@@ -1367,6 +1367,8 @@ class AdvancedTag(object):
         '''
         return DOMTokenList(self._classNames[:])
 
+    classNames = classList
+
     def getUid(self):
         '''
             getUid - Get the AdvancedHTMLParser unique id for this tag.
@@ -1400,7 +1402,8 @@ class AdvancedTag(object):
         # Get all attributes as a tuple (name<str>, value<str>)
         for name, val in self._attributes.items():
             # Get all attributes
-            val = tostr(val)
+            if val:
+                val = tostr(val)
 
             # Only binary attributes have a "present/not present"
             if val or name not in TAG_ITEM_BINARY_ATTRIBUTES:
@@ -1487,8 +1490,19 @@ class AdvancedTag(object):
         '''
             getAttribute - Gets an attribute on this tag. Be wary using this for classname, maybe use addClass/removeClass. Attribute names are all lowercase.
                 @return - The attribute value, or None if none exists.
-           '''
-        return self._attributes.get(attrName, defaultValue)
+        '''
+
+        if attrName in TAG_ITEM_BINARY_ATTRIBUTES:
+            if attrName in self._attributes:
+                attrVal = self._attributes[attrName]
+                if not attrVal:
+                    return True # Empty valued binary attribute
+
+                return attrVal # optionally-valued binary attribute
+            else:
+                return False
+        else:
+            return self._attributes.get(attrName, defaultValue)
 
 
     def getAttributesList(self):
