@@ -6,6 +6,8 @@ from .conversions import ( convertToIntOrNegativeOneIfUnset, convertToPositiveIn
     convertPossibleValues, convertToIntRange, convertToIntRangeCapped, EMPTY_IS_INVALID
 )
 
+from .exceptions import IndexSizeErrorException
+
 # These tags are always self-closing, whether given that way or not.
 IMPLICIT_SELF_CLOSING_TAGS = set(['meta', 'link', 'input', 'img', 'hr', 'br'])
 
@@ -73,7 +75,6 @@ TAG_NAMES_TO_ADDITIONAL_ATTRIBUTES = {
                 'src', 'srcset', 'useMap', 'vspace', 'width'},
     # TODO: input->formAction, formEnctype default to current url but we don't know it
     # TODO: input->list default is null
-    # TODO: input->maxLength throws exception when negative value instead of default
     # TODO: input->size seems to have some sort of default value in firefox (20?)
     # TODO: input->size is an integer through dot-access, also throws exception on invalid value
     # TODO: input->size has a minimum value of 1
@@ -273,7 +274,7 @@ def _special_value_autocomplete(em):
     # else: input
     return convertPossibleValues(em.getAttribute('autocomplete', ''), POSSIBLE_VALUES_ON_OFF, invalidDefault="", emptyValue='')
 
-def _special_size(em):
+def _special_value_size(em):
     '''
         handle "size" property, which has different behaviour for input vs everything else
     '''
@@ -285,6 +286,48 @@ def _special_size(em):
     return em.getAttribute('size', '')
 
 
+class NOT_PROVIDED_TYPE(object):
+    '''
+        NOT_PROVIDED_TYPE - A type for a singleton which is meant to mean "Argumnent not provided"
+
+            (since None, empty string, etc are legitimate possible values
+    '''
+    pass
+ 
+# NOT_PROVIDED - Singleton of NOT_PROVIDED_TYPE, used to indicate that an argument is not provided
+NOT_PROVIDED = NOT_PROVIDED_TYPE()
+
+def _special_value_maxLength(em, newValue=NOT_PROVIDED):
+    '''
+        _special_value_maxLength - Handle the special "maxLength" property
+
+            @param em <AdvancedTag> - The tag element
+
+            @param newValue - Default NOT_PROVIDED, if provided will use that value instead of the
+
+                current .getAttribute value on the tag. This is because this method can be used for both validation
+                 
+                and getting/setting
+    '''
+    
+    if newValue is NOT_PROVIDED:
+        if not em.hasAttribute('maxlength'):
+            return -1
+
+        curValue = em.getAttribute('maxlength', '-1')
+
+        # If we are accessing, the invalid default should be negative
+        invalidDefault = -1
+    else:
+        curValue = newValue
+
+        # If we are setting, we should raise an exception upon invalid value
+        invalidDefault = IndexSizeErrorException
+
+    return convertToIntRange(curValue, minValue=0, maxValue=None, emptyValue='0', invalidDefault=invalidDefault)
+
+
+
 def _DOMTokenList_type(*args):
     '''
         _DOMTokenList_type - A method which imports and returns SpecialAttributes.DOMTokenList
@@ -301,6 +344,9 @@ def _DOMTokenList_type(*args):
     return DOMTokenList
 
 
+# IndexSizeError - Singleton for the IndexSizeErrorException type
+IndexSizeError = IndexSizeErrorException()
+
 # TODO: Send firefox some bug reports based on below info
 
 # These attributes can have a special value
@@ -314,10 +360,9 @@ TAG_ITEM_ATTRIBUTES_SPECIAL_VALUES = {
     'rowSpan'     : lambda em : convertToIntRangeCapped(em.getAttribute('rowspan', 1), minValue=0, maxValue=65534, invalidDefault=0),
     'hspace'     : lambda em : convertToPositiveInt(em.getAttribute('hspace', 0), invalidDefault=0),
     'vspace'     : lambda em : convertToPositiveInt(em.getAttribute('vspace', 0), invalidDefault=0),
-    # maxLength needs to throw exception on invalid
-    'maxLength'     : lambda em : convertToPositiveInt(em.getAttribute('maxlength', -1), invalidDefault=-1),
+    'maxLength'     : _special_value_maxLength,
     # size throws exception on invalid value, and a minimum of 1
-    'size'     : _special_size,
+    'size'     : _special_value_size,
     # crossOrigin is "use-credentials" or "anonymous" (all invalid values go to anonymous) default null
     'crossOrigin' : lambda em : convertPossibleValues(em.getAttribute('crossorigin', None), POSSIBLE_VALUES_CROSS_ORIGIN, invalidDefault="anonymous", emptyValue=None),
     # autocomplete has different behaviour for "input" vs "form"
@@ -333,3 +378,11 @@ TAG_ITEM_ATTRIBUTES_SPECIAL_VALUES = {
 
 }
 
+
+# TAG_ITEM_ATTRIBUTES_SPECIAL_VALIDATION - These perform a validation step when setting the value via AdvancedTag.${NAME} = something
+#    Key should be the . access name, value is a function/lambda which takes the element as first argument, and the new value as the second argument.
+TAG_ITEM_ATTRIBUTES_SPECIAL_VALIDATION = {
+    'maxLength' : _special_value_maxLength,
+}
+
+
